@@ -1,7 +1,6 @@
 /* ugexe@cpan.org (Nick Logan)    */
 
 #define MIN(a,b) (((a)<(b))?(a):(b))
-#define MAX(a,b) (((a)>(b))?(a):(b))
 
 
 /* Our unsorted dictionary linked list.   */
@@ -70,11 +69,10 @@ static void dict_free(item* head){
 
 static int distance(unsigned int src[],unsigned int tgt[],unsigned int x,unsigned int y,unsigned int maxDistance){
   item *head = NULL;
-  unsigned int xy_max = MAX(x,y);
-  unsigned int db,i1,j1,i,j;
+  unsigned int swapCount,swapScore,targetCharCount,i,j;
   unsigned int *scores = malloc( (x + 2) * (y + 2) * sizeof(unsigned int) );
   unsigned int score_ceil = x + y;
-
+ 
   /* intialize matrix start values */
   scores[0] = score_ceil;  
   scores[1 * (y + 2) + 0] = score_ceil;
@@ -82,13 +80,15 @@ static int distance(unsigned int src[],unsigned int tgt[],unsigned int x,unsigne
   scores[1 * (y + 2) + 1] = 0;
   head = uniquePush(uniquePush(head,src[0]),tgt[0]);
 
-  /* work loop */
+  /* work loops    */
+  /* i = src index */
+  /* j = tgt index */
   for(i=1;i<=x;i++){ 
     head = uniquePush(head,src[i]);
     scores[(i+1) * (y + 2) + 1] = i;
     scores[(i+1) * (y + 2) + 0] = score_ceil;
 
-    db = 0;
+    swapCount = 0;
     for(j=1;j<=y;j++){
       if(i == 1) {
           head = uniquePush(head,tgt[j]);
@@ -96,17 +96,15 @@ static int distance(unsigned int src[],unsigned int tgt[],unsigned int x,unsigne
           scores[0 * (y + 2) + (j + 1)] = score_ceil;
       }
 
-      i1 = find(head,tgt[j-1])->value;
-      j1 = db;
+      targetCharCount = find(head,tgt[j-1])->value;
+      swapScore = scores[targetCharCount * (y + 2) + swapCount] + i - targetCharCount - 1 + j - swapCount;
 
-      if(src[i-1] == tgt[j-1]){
-        scores[(i+1) * (y + 2) + (j + 1)] = scores[i * (y + 2) + j];
-        db = j;
+      if(src[i-1] != tgt[j-1]){      
+        scores[(i+1) * (y + 2) + (j + 1)] = MIN(swapScore,(MIN(scores[i * (y + 2) + j], MIN(scores[(i+1) * (y + 2) + j], scores[i * (y + 2) + (j + 1)])) + 1));
       }else{ 
-        scores[(i+1) * (y + 2) + (j + 1)] = MIN(scores[i * (y + 2) + j], MIN(scores[(i+1) * (y + 2) + j], scores[i * (y + 2) + (j + 1)])) + 1;
+        swapCount = j;
+        scores[(i+1) * (y + 2) + (j + 1)] = MIN(scores[i * (y + 2) + j], swapScore);
       } 
-
-      scores[(i+1) * (y + 2) + (j + 1)] = MIN(scores[(i+1) * (y + 2) + (j + 1)], (scores[i1 * (y + 2) + j1] + i - i1 - 1 + j - j1));
     }
 
     /* We will return -1 here if the */
@@ -127,4 +125,4 @@ static int distance(unsigned int src[],unsigned int tgt[],unsigned int x,unsigne
   free(scores);
   return score;
   }
-}
+}
\ No newline at end of file
